@@ -1,41 +1,34 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 import logging
 
 from django.contrib import admin, messages
 from django.contrib.auth.models import User
-from django.contrib.sites.models import get_current_site
+try:
+    from django.contrib.sites.models import get_current_site
+except ImportError:
+    from django.contrib.sites.shortcuts import get_current_site
 from django.core.mail import EmailMultiAlternatives
 from django.core.urlresolvers import reverse
 from django.template.loader import render_to_string
 from django.utils import translation
 from django.utils.translation import ugettext_lazy as _, ungettext_lazy
+
 from django_mobile_app_distribution import settings as _settings
 from django_mobile_app_distribution.models import IosApp, AndroidApp
-
-from forms import IosAppAdminForm, AppAdminForm
-from models import UserInfo
+from django_mobile_app_distribution.forms import iOSAppAdminForm, AndroidAppAdminForm
+from django_mobile_app_distribution.models import UserInfo
 
 
-log = logging.getLogger(__name__)
-
-###################################################################################
-# Avoid overriding the User in case other apps already do that, deprecated in 0.1.2
-###################################################################################
-
-# Define an inline admin descriptor for UserInfo model
-# which acts a bit like a singleton
-# class UserInfoInline(admin.StackedInline):
-#     model = UserInfo
-#     can_delete = False
-
-# class UserAdmin(admin.ModelAdmin):
-#     inlines = (UserInfoInline, )
+logger = logging.getLogger(__name__)
 
 
 class UserInfoAdmin(admin.ModelAdmin):
     model = UserInfo
     list_display = ['user', 'language']
     list_editable = ['language']
+    search_fields = ['user__username']
+
 
 class NotifiableModelAdmin(admin.ModelAdmin):
     actions = ['notify_client']
@@ -68,19 +61,27 @@ class NotifiableModelAdmin(admin.ModelAdmin):
                 except Exception:
                     pass
 
+                domain = get_current_site(request).domain
+                index_url = reverse('django_mobile_app_distribution_index')
                 data = {
-                    'email_link_color_hex' : _settings.EMAIL_LINK_COLOR_HEX,
-                    'app_name' : app.name,
-                    'app_version' : app.version,
+                    'email_link_color_hex': _settings.EMAIL_LINK_COLOR_HEX,
+                    'app_name': app.name,
+                    'app_version': app.version,
                     'os': app.operating_system,
-                    'download_url' : '/'.join(s.strip('/') for s in (get_current_site(request).domain, reverse('django_mobile_app_distribution_index')))
+                    'download_url': '/'.join(s.strip('/') for s in (domain, index_url))
                 }
 
                 email = EmailMultiAlternatives()
                 email.bcc = recipients
                 email.subject = _('Version %(app_version)s of %(app_name)s for %(os)s is available for download') % data
-                email.body = _('Version %(app_version)s of %(app_name)s for %(os)s is available for download.\nPlease visit %(download_url)s to install the app.') % data
-                email.attach_alternative(render_to_string('django_mobile_app_distribution/email_notification.html', data), 'text/html')
+                email.body = _(
+                    'Version %(app_version)s of %(app_name)s for %(os)s is available for download.\n'
+                    'Please visit %(download_url)s to install the app.'
+                ) % data
+                email.attach_alternative(
+                    render_to_string('django_mobile_app_distribution/email_notification.html', data),
+                    'text/html'
+                )
 
                 # Reset to system language
                 translation.deactivate()
@@ -98,7 +99,10 @@ class NotifiableModelAdmin(admin.ModelAdmin):
                         },
                     fail_silently=True)
             else:
-                messages.add_message(request, messages.ERROR, _('Nobody was notified by email because nobody\'s email address is set.'), fail_silently=True)
+                messages.add_message(
+                    request, messages.ERROR, _('Nobody was notified by email because nobody\'s email address is set.'),
+                    fail_silently=True
+                )
     notify_client.short_description = _('Notify clients of app availability')
 
     def user_display_name(self, instance):
@@ -116,9 +120,9 @@ class NotifiableModelAdmin(admin.ModelAdmin):
             return ''
     groups_display_name.short_description = _('Groups')
 
-class IosAppAdmin(NotifiableModelAdmin):
 
-    form = IosAppAdminForm
+class IosAppAdmin(NotifiableModelAdmin):
+    form = iOSAppAdminForm
     list_display = ('name', 'user_display_name', 'groups_display_name', 'version', 'comment', 'updatedAt')
     filter_horizontal = ['groups']
 
@@ -126,11 +130,14 @@ class IosAppAdmin(NotifiableModelAdmin):
         (_('App info'), {
             'fields': ('user', 'groups', 'name', 'version', 'bundle_identifier', 'app_binary', 'comment')
         }),
+        (_('Provide these deploy on iOS 9'), {
+            'fields': ('display_image', 'full_size_image')
+        }),
     )
 
-class AndroidAppAdmin(NotifiableModelAdmin):
 
-    form = AppAdminForm
+class AndroidAppAdmin(NotifiableModelAdmin):
+    form = AndroidAppAdminForm
     list_display = ('name', 'user_display_name', 'groups_display_name', 'version', 'comment', 'updatedAt')
     filter_horizontal = ['groups']
 
@@ -140,12 +147,7 @@ class AndroidAppAdmin(NotifiableModelAdmin):
         }),
     )
 
+
 admin.site.register(IosApp, IosAppAdmin)
 admin.site.register(AndroidApp, AndroidAppAdmin)
 admin.site.register(UserInfo, UserInfoAdmin)
-
-###################################################################################
-# Avoid overriding the User in case other apps already do that, deprecated in 0.1.2
-###################################################################################
-# admin.site.unregister(User)
-# admin.site.register(User, UserAdmin)
