@@ -1,5 +1,6 @@
-
+# -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 
 class MobileAppDistributionConfigurationException(Exception):
     """A misconfiguration within the Django Mobile App Distribution settings is causing invalid states"""
-    pass
\ No newline at end of file
+    pass
