@@ -1,21 +1,25 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 import logging
 import os.path
 from itertools import chain
 from operator import attrgetter
 from os.path import basename
+from wsgiref.util import FileWrapper
 
+from future.builtins import (int, map, open)
 from django.contrib.auth.decorators import login_required
-from django.contrib.sites.models import get_current_site
-from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
-from django.core.servers.basehttp import FileWrapper
+try:
+    from django.contrib.sites.models import get_current_site
+except ImportError:
+    from django.contrib.sites.shortcuts import get_current_site
+from django.core.exceptions import MultipleObjectsReturned
 from django.http import HttpResponse, HttpResponseForbidden, Http404
 from django.shortcuts import render
 from django.utils import translation
 
-import settings as app_dist_settings
-from models import IosApp, AndroidApp, UserInfo
-
+import django_mobile_app_distribution.settings as app_dist_settings
+from django_mobile_app_distribution.models import IosApp, AndroidApp, UserInfo
 
 log = logging.getLogger(__name__)
 
@@ -46,18 +50,18 @@ def index(request):
     apps.sort(key=attrgetter('name'))
 
     return render(request, 'django_mobile_app_distribution/app_list.html', {
-        'apps' : apps,
-        'ios_identifier' : app_dist_settings.IOS,
-        'site_url' : get_current_site(request).domain
-        })
+        'apps': apps,
+        'ios_identifier': app_dist_settings.IOS,
+        'site_url': get_current_site(request).domain
+    })
 
 
 @login_required
 def send_apk(request, app_id):
     """
-    Send a file through Django without loading the whole file into              
-    memory at once. The FileWrapper will turn the file object into an           
-    iterator for chunks of 8KB.                                                 
+    Send a file through Django without loading the whole file into
+    memory at once. The FileWrapper will turn the file object into an
+    iterator for chunks of 8KB.
     """
     android_app = None
     try:
@@ -72,9 +76,9 @@ def send_apk(request, app_id):
 
     if not authenticated:
         app_group_ids = android_app.groups.all().values_list('pk', flat=True)
-        app_group_ids = list(map(long, app_group_ids))
+        app_group_ids = list(map(int, app_group_ids))
         for user_group in request.user.groups.all():
-            user_group_id = long(user_group.id)
+            user_group_id = int(user_group.id)
             if user_group_id in app_group_ids:
                 authenticated = True
                 break
@@ -82,10 +86,11 @@ def send_apk(request, app_id):
     if not authenticated:
         return HttpResponseForbidden('This is not your app')
 
-    filename = os.path.join(app_dist_settings.MOBILE_APP_DISTRIBUTION_ANDROID_FILE_STORAGE_PATH, android_app.app_binary.name)
-
-    wrapper = FileWrapper(file(filename))
-    response = HttpResponse(wrapper)
+    filename = os.path.join(
+        app_dist_settings.MOBILE_APP_DISTRIBUTION_ANDROID_FILE_STORAGE_PATH,
+        android_app.app_binary.name
+    )
+    response = HttpResponse(FileWrapper(open(filename, 'rb')))
     response['Content-Length'] = os.path.getsize(filename)
     response['Content-Type'] = app_dist_settings.MOBILE_APP_DISTRIBUTION_CONTENT_TYPES[android_app.operating_system]
     response['Content-Disposition'] = 'inline; filename=%s' % basename(filename)
@@ -101,10 +106,20 @@ def ios_app_plist(request, app_id):
         raise Http404
 
     from . import settings as mad_settings
-    plist_string = mad_settings.IOS_PLIST_BLUEPRINT
-    plist_string = plist_string.replace(mad_settings.PLIST_APP_URL, ios_app.get_binary_url())
-    plist_string = plist_string.replace(mad_settings.PLIST_BUNDLE_IDENTIFIER, ios_app.bundle_identifier)
-    plist_string = plist_string.replace(mad_settings.PLIST_BUNDLE_VERSION, ios_app.version)
-    plist_string = plist_string.replace(mad_settings.PLIST_APP_TITLE, ios_app.name)
+    plist = ''
+    if ios_app.display_image and ios_app.full_size_image:
+        plist = mad_settings.IOS_PLIST_BLUEPRINT_IOS9
+        plist = plist.replace(mad_settings.PLIST_DISPLAY_IMAGE, ios_app.get_display_image_url())
+        plist = plist.replace(mad_settings.PLIST_FULL_SIZE_IMAGE, ios_app.get_full_size_image_url())
+    else:
+        plist = mad_settings.IOS_PLIST_BLUEPRINT
 
-    return HttpResponse(plist_string, content_type=mad_settings.MOBILE_APP_DISTRIBUTION_CONTENT_TYPES[mad_settings.IOS_PLIST])
\ No newline at end of file
+    plist = plist.replace(mad_settings.PLIST_APP_URL, ios_app.get_binary_url())
+    plist = plist.replace(mad_settings.PLIST_BUNDLE_IDENTIFIER, ios_app.bundle_identifier)
+    plist = plist.replace(mad_settings.PLIST_BUNDLE_VERSION, ios_app.version)
+    plist = plist.replace(mad_settings.PLIST_APP_TITLE, ios_app.name)
+
+    return HttpResponse(
+        plist,
+        content_type=mad_settings.MOBILE_APP_DISTRIBUTION_CONTENT_TYPES[mad_settings.IOS_PLIST]
+    )
